
%--------------------------------------------------------------------------
% EXAMPLE OF INPUT FILE TO PLOT A PHASE DIAGRAM FOR Cu5 + OXYGEN CLUSTERS
% WITH OR WITHOUT A SUPPORT
%--------------------------------------------------------------------------
% AUTHORS: JAIME GARRIDO ALDEA 
%--------------------------------------------------------------------------
clear all %do not delete this!!

% Important remark: all .out files must be named in the following way:
% N.out where N is the total number of O2 molecules.

integers=[0:2:10];
integers=[integers 11 12 14];% vector that contains the number of O2 molecules of each
%ORCA output file. Remember that all files should be named like N.out. This
%way, integers(i).out is the name of the ORCA output file with integers(i)
%O2 molecules.
%----------------------------------------------------------------------------------
gasfile='free_O2.out';% name of the ORCA output file of the free gas. In this case
% oxygen
%---------------------------------------------------------------------------------
freecluster='0.out';% name of the ORCA out file with the cluster without oxygen
% REMARK: Do not change this variable. This variable is included in case of
% future improvements.
%---------------------------------------------------------------------------------
format='omega_O2_dimer_';%format of the output files with the omega
% matrices. At the end of the format, an integer with the total number of
% 02 molecules will be added
%-----------------------------------------------------------------------------------------------------------
writeFile=0; %set to 1 if you want to write the omega matrix in a txt file with a name with
% the structure given in the variable 'format'
%----------------------------------------------------------------------------------
title='Phase Diagram (Cu_5 - CU_5) - (0_2)_{2n}'; %title of the figure that will be plotted. Suggested titles:
% 'Phase Diagram (Cu_5) - (0_2)_{n} + support'
% 'Phase Diagram (Cu_5) - (0_2)_{n}'
% 'Phase Diagram (Cu_5 - CU_5) - (0_2)_{2n}'
% 'Phase Diagram (Cu_5 - CU_5) - (0_2)_{2n} + support'
%----------------------------------------------------------------------------------
T=[0:1:500]; %Temperature range (in Celsius) for the phase diagram. ORCA calculates thermodynamic
% variables for certain temperatures. For the rest of the temperatures, an interpolation is made. 
% The interpolation is then evaluated at this vector. 
% REMEMBER: T=[initialValue: step : Final value];
%----------------------------------------------------------------------------------
y=[-300:1:1300]; %Vector used for the pressure dependence. The actual pressure is calculated
% the following way:
p=1*10.^(-y./100);  %in bar
%--------------------------------------------------------------------------------------------
isDimer=1; % 0 if is not a dimer. 1 if it is a dimer. 
%---------------------------------------------------------------------------------------------
%COLORMAP USED FOR THE PLOT
black=[0 0 0];
white=[255 255 255];
goldenrod=[255 192 32];
darkred=[139 0 0];
grey30=[77 77 77];
lightgoldenrod=[238 221 130];
lightpink=[255 182 193];
forestgreen=[34 139 34];
midnightblue=[25 25 112];
salmon=[250 128 114];
orchid4=[128 64 128];
slategrey=[160 182 205];
seagreen=[193 255 193];
% DO NOT FORGET TO DIVIDE BY 255

colorMatrix=(1/255)*[darkred; black; white; goldenrod; grey30; lightgoldenrod; ...
    lightpink; midnightblue; ...
    forestgreen; salmon; orchid4; slategrey; seagreen];
% If you want to use a default octave colormap, set colorMatrix=[];
% Default colormap used: jet
%--------------------------------------------------------------------------


phaseDiagramGenerator(integers,gasfile,freecluster,format,title...
    ,T,p,isDimer,colorMatrix,writeFile);
