function OMEGA=omega(N,gasfile,freecluster,cluster,filename,T,p,isDimer,writeFile)
% Matlab function to generate the grand canonical potential omega
% as a function of pressure and temperature
% Jaime Garrido Aldea and María Pilar de Lara-Castells
%--------------------------------------------------------------------------
% Constants
h2kcal = 627.50960;
j2cal  = 1/4.184;
eV2kcal = 23.060542;
R = 1.9872156/1000; % in kcal/(mol*K)
%--------------------------------------------------------------------------

[omega_no_mu_data,T_data]=ORCA_READ(gasfile,freecluster,cluster,N,isDimer);
%T_d is in K. We need it in Celsius:
T_data=T_data-273.15;
% Now, we interpolate with splines and evaluate at the values in T.
omega_no_mu = spline(T_data,omega_no_mu_data,T);

% Get Enthalpy and Entropy of gas molecule from NIST
nist = load('NIST_O2.txt');
T_data = nist(:,1) -273.15;              % NIST T in K
h_gas_data = nist(:,5)*j2cal;            % NIST H is in kJ/mol
h_gas_data = h_gas_data - nist(1,5)*j2cal;  % delta_H between T and T=0K
s_gas_data = nist(:,3)*j2cal/1000;       % NIST S is in J/mol

% Now, we interpolate with splines and evaluate at the values in T.
h_gas = spline(T_data,h_gas_data,T);
% Now, we interpolate with splines and evaluate at the values in T.
s_gas = spline(T_data,s_gas_data,T);

mu_0 = h_gas - (T+273.15).*(s_gas + R*log(1.033));  % in kcal/mol

OMEGA = zeros(11,length(T));
for i=1:length(p)
    mu = mu_0 + R*(T+273.15)*log(p(i)); % mu(T) -> mu(p,T)
    OMEGA(i,:) = (omega_no_mu - mu*N);
end

if writeFile==1
storefile = [filename,num2str(N),'.txt'];
dlmwrite(storefile,OMEGA);
end
